@@ -1,6 +1,12 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 """
+The geneticoptimizer module provides optimizers and wrappers for GA.
+
+As for now I didn't tried a convincing Genetic Algorithm library. This is why
+you can either use PyGAD or the builtt-in version. The switch between versions
+is made automatically on wether or not you have PyGAD installed.
+
 Created on Thu Jun 10 21:20:47 2021.
 
 @author: HugoFara
@@ -224,7 +230,7 @@ def evolutionnary_optimization(
     prob : TYPE
         DESCRIPTION.
     fitness : callable
-        Evaluation function for an OPTIMIZATION problem.
+        Evaluation function for an %AXIMISATION problem.
         Must return a float.
     ite : int
         Number of iterations.
@@ -273,7 +279,8 @@ def evolutionnary_optimization(
     # Legacy fallback
     return evolutionnary_optimization_legacy(
         dna, prob, fitness, ite,
-        max_pop=max_pop, init_pop=init_pop,
+        max_pop=max_pop,
+        init_pop=len(init_pop),
         max_genetic_dist=max_genetic_dist,
         startnstop=startnstop,
         fitness_args=fitness_args
